@@ -2,7 +2,6 @@ import json
 import os
 import pathlib
 import time
-import warnings
 from typing import Optional, List, Set, Dict, Union
 
 import git
@@ -18,6 +17,7 @@ from labml.internal.logger import logger_singleton as logger_internal
 from labml.internal.util import is_ipynb, is_colab, is_kaggle
 from labml.logger import Text
 from labml.utils import get_caller_file
+from labml.utils.notice import labml_notice
 
 
 class ModelSaver:
@@ -34,6 +34,7 @@ class CheckpointSaver:
     def __init__(self, path: pathlib.PurePath):
         self.path = path
         self.model_savers = {}
+        self.__no_savers_warned = False
 
     def add_savers(self, models: Dict[str, ModelSaver]):
         """
@@ -47,6 +48,11 @@ class CheckpointSaver:
         """
 
         if not self.model_savers:
+            if not self.__no_savers_warned:
+                labml_notice(["No models were registered for saving\n",
+                              "You can register models with ",
+                              ('experiment.add_pytorch_models', Text.value)])
+                self.__no_savers_warned = True
             return
 
         checkpoints_path = pathlib.Path(self.path)
@@ -71,21 +77,40 @@ class CheckpointSaver:
         ## Load model as a set of numpy arrays
         """
 
-        if not self.model_savers:
-            return False
-
         if not models:
             models = list(self.model_savers.keys())
 
         with open(str(checkpoint_path / "info.json"), "r") as f:
             info = json.loads(f.readline())
 
-        # Load each model
+        to_load = []
+        not_loaded = []
+        missing = []
         for name in models:
+            if name not in info:
+                missing.append(name)
+            else:
+                to_load.append(name)
+        for name in info:
+            if name not in models:
+                not_loaded.append(name)
+
+        # Load each model
+        for name in to_load:
             saver = self.model_savers[name]
             saver.load(checkpoint_path, info[name])
 
-        return True
+        if missing:
+            labml_notice([(f'{missing} ', Text.highlight),
+                          ('model(s) could not be found.\n'),
+                          (f'{to_load} ', Text.none),
+                          ('models were loaded.', Text.none)
+                          ], is_danger=True)
+        if not_loaded:
+            labml_notice([(f'{not_loaded} ', Text.none),
+                          ('models were not loaded.\n', Text.none),
+                          'Models to be loaded should be specified with: ',
+                          ('experiment.add_pytorch_models', Text.value)])
 
 
 class Experiment:
@@ -116,7 +141,8 @@ class Experiment:
                  comment: Optional[str],
                  writers: Set[str],
                  ignore_callers: Set[str],
-                 tags: Optional[Set[str]]):
+                 tags: Optional[Set[str]],
+                 is_evaluate: bool):
         if python_file is None:
             python_file = get_caller_file(ignore_callers)
 
@@ -147,10 +173,6 @@ class Experiment:
 
         self.configs_processor = None
 
-        experiment_path = pathlib.Path(self.experiment_path)
-        if not experiment_path.exists():
-            experiment_path.mkdir(parents=True)
-
         if tags is None:
             tags = set(name.split('_'))
 
@@ -170,8 +192,8 @@ class Experiment:
             self.run.diff = repo.git.diff()
         except git.InvalidGitRepositoryError:
             if not is_colab() and not is_kaggle():
-                warnings.warn(f"Not a valid git repository",
-                              UserWarning, stacklevel=4)
+                labml_notice(["Not a valid git repository: ",
+                              (lab_singleton().path, Text.value)])
             self.run.commit = 'unknown'
             self.run.commit_message = ''
             self.run.is_dirty = True
@@ -197,6 +219,7 @@ class Experiment:
             self.web_api = None
 
         self.checkpoint_saver = CheckpointSaver(self.run.checkpoint_path)
+        self.is_evaluate = is_evaluate
 
     def __print_info(self):
         """
@@ -230,8 +253,7 @@ class Experiment:
             ])
 
     def _load_checkpoint(self, checkpoint_path: pathlib.Path):
-        if not self.checkpoint_saver.load(checkpoint_path):
-            logger.log('No models registered', Text.warning)
+        self.checkpoint_saver.load(checkpoint_path)
 
     def save_checkpoint(self):
         self.checkpoint_saver.save(logger_internal().global_step)
@@ -283,8 +305,7 @@ class Experiment:
             checkpoint)
 
         if global_step is None:
-            warnings.warn(f"Could not find checkpoint",
-                          UserWarning, stacklevel=4)
+            labml_notice(['Could not find saved checkpoint'], is_danger=True)
             return
 
         with monit.section("Loading checkpoint"):
@@ -312,10 +333,13 @@ class Experiment:
         if self.configs_processor is not None:
             self.configs_processor.print()
 
-        self.run.save_info()
+        if not self.is_evaluate:
+            self.run.save_info()
 
-        if self.configs_processor is not None:
-            self.configs_processor.save(self.run.configs_path)
+            if self.configs_processor is not None:
+                self.configs_processor.save(self.run.configs_path)
+
+            logger_internal().save_indicators(self.run.indicators_path)
 
         if self.web_api is not None:
             self.web_api.set_info(run_uuid=self.run.uuid,
@@ -325,19 +349,19 @@ class Experiment:
                 self.web_api.set_configs(self.configs_processor.to_json())
             self.web_api.start()
 
-        logger_internal().save_indicators(self.run.indicators_path)
         if self.configs_processor:
             logger_internal().write_h_parameters(self.configs_processor.get_hyperparams())
 
         return ExperimentWatcher(self)
 
     def finish(self, status: str, details: any = None):
-        with open(str(self.run.run_log_path), 'a') as f:
-            end_time = time.time()
-            data = json.dumps({'status': status,
-                               'details': details,
-                               'time': end_time}, indent=None)
-            f.write(data + '\n')
+        if not self.is_evaluate:
+            with open(str(self.run.run_log_path), 'a') as f:
+                end_time = time.time()
+                data = json.dumps({'status': status,
+                                   'details': details,
+                                   'time': end_time}, indent=None)
+                f.write(data + '\n')
 
         if self.web_api is not None:
             self.web_api.status(status, details, end_time)
@@ -376,7 +400,8 @@ def create_experiment(*,
                       comment: Optional[str],
                       writers: Set[str],
                       ignore_callers: Set[str],
-                      tags: Optional[Set[str]]):
+                      tags: Optional[Set[str]],
+                      is_evaluate: bool):
     global _internal
 
     _internal = Experiment(name=name,
@@ -384,4 +409,5 @@ def create_experiment(*,
                            comment=comment,
                            writers=writers,
                            ignore_callers=ignore_callers,
-                           tags=tags)
+                           tags=tags,
+                           is_evaluate=is_evaluate)
