@@ -28,7 +28,7 @@ class IpynbDestination(Destination):
         return False
 
     @staticmethod
-    def __html_code(text: str, color: List[StyleCode] or StyleCode or None):
+    def html_code(text: str, color: List[StyleCode] or StyleCode or None):
         """
         ### Add ansi color codes
         """
@@ -39,11 +39,11 @@ class IpynbDestination(Destination):
         if color is None:
             return text
         elif isinstance(color, list):
-            open_tags = ''.join([c.html_open() for c in color])
-            close_tags = ''.join([c.html_close() for c in reversed(color)])
+            open_tags = ''.join([c.html_open(text) for c in color])
+            close_tags = ''.join([c.html_close(text) for c in reversed(color)])
         else:
-            open_tags = color.html_open()
-            close_tags = color.html_close()
+            open_tags = color.html_open(text)
+            close_tags = color.html_close(text)
 
         return open_tags + text + close_tags
 
@@ -62,7 +62,7 @@ class IpynbDestination(Destination):
                 tuple_parts.append(('\n', None))
             tuple_parts.append((lines[-1], style))
 
-        coded = [self.__html_code(text, color) for text, color in tuple_parts]
+        coded = [self.html_code(text, color) for text, color in tuple_parts]
 
         text = "".join(coded)
         lines = text.split('\n')
