@@ -175,7 +175,7 @@ class Writer(WriteBase):
         if url is None:
             return None
 
-        logger.log([('Monitor experiment at ', Text.meta), (url, Text.highlight)])
+        logger.log([('Monitor experiment at ', Text.meta), (url, Text.link)])
         if self.web_api.open_browser:
             webbrowser.open(url)
 
